@@ -14,8 +14,7 @@
 
 
 #####################################################
-def uvmodelfit(xds, field=None, spw=None, timerange=None, uvrange=None, antenna=None, scan=None, niter=5, comptype='p', sourcepar=[1, 0, 0],
-               varypar=[]):
+def uvmodelfit(xds, niter=5, comptype='p', sourcepar=[1, 0, 0], varypar=[]):
     """
     .. todo::
         This function is not yet implemented
@@ -26,18 +25,6 @@ def uvmodelfit(xds, field=None, spw=None, timerange=None, uvrange=None, antenna=
     ----------
     xds : xarray.core.dataset.Dataset
         input Visibility Dataset
-    field : int
-        field selection. If None, use all fields
-    spw : int
-        spw selection. If None, use all spws
-    timerange : int
-        time selection. If None, use all times
-    uvrange : int
-        uvrange selection. If None, use all uvranges
-    antenna : int
-        antenna selection. If None, use all antennas
-    scan : int
-        scan selection. If None, use all scans
     niter : int
         number of fitting iteractions to execute
     comptype : str
